# DEVELOP

cd jupyterlab_athena_analytics

### install
npm install



### Build Extension
```
pip install -e .
```


### Serve to view in jupyter
```
cd ~/workspace/notebooks
pyenv activate jupyter_env
jupyter lab --ServerApp.tornado_settings="{\"headers\": {\"Content-Security-Policy\": \"frame-ancestors 'self' https://app.athenaintelligence.ai https://staging-app.athenaintelligence.ai http://localhost:8081;\"}}"
```


# BG Notes

# Workflow
1. Bump a version using hatch
2. Follow the release instructions

## Bump Version

or a patch version (bumps 0.2.0 -> 0.2.1)
```bash
hatch version patch
```


Release a minor version (bumps 0.2.0 -> 0.3.0)
```bash
hatch version minor
```


or a major version (bumps 0.2.0 -> 1.0.0)
```bash
hatch version major
```
Go to: https://pypi.org/manage/account/token/ for your username/token

## Release Instructions

`pip install build` YOU NEED THIS FIRST

Go to RELEASE.md and follow the instructions to release the package
1. `jlpm clean:all`
2. `git clean -dfX`
3. `python -m build`
4. `twine upload dist/*`


# Deprecated below

## Publish
```bash
hatch publish
```
For username just click enter and for Credentials put in your token from the pypi website or as follows: 

### token
```
pypi-AgEIcHlwaS5vcmcCJDIxOTBlNmFjLWY0YzItNDMwMy1hYTgwLTc4ZmM0MjJjMGI1MgACI1sxLFsianVweXRlcmxhYi1hdGhlbmEtYW5hbHl0aWNzIl1dAAIsWzIsWyJiZWY1ZGM2Ny02NGE4LTQ4ODYtOWM2ZC02M2M1YzVmNWVmNGEiXV0AAAYgxX-0Ec9kVZAAr47iGSGFdxTW6ev0PY1iuO3ZMt1ssyo
```

Sample output:
```bash
dist/jupyterlab_athena_analytics-0.3.0-py3-none-any.whl ...
success
dist/jupyterlab_athena_analytics-0.2.0.tar.gz ... already exists
dist/jupyterlab_athena_analytics-0.3.0.tar.gz ... success
dist/jupyterlab_athena_analytics-0.2.0-py3-none-any.whl ... already exists
```

Now you can install the package using pip w/ latest version
```bash
pip install jupyterlab_athena_analytics@latest
```

or a specific version
```bash
pip install jupyterlab_athena_analytics@0.3.0
```


___ 

# Athena Notes

```
python3 setup.py sdist bdist_wheel
```


https://app.athenaintelligence.ai/dashboard/chat/conv_c3488539-da41-4110-8dc4-d6abb0879170/

```bash
jlpm install
jlpm run build
```

```bash
pip install -e .
jupyter labextension install .
```





# jupyterlab_athena_analytics

[![Github Actions Status](https://github.com/github_username/jupyterlab_athena_analytics/workflows/Build/badge.svg)](https://github.com/github_username/jupyterlab_athena_analytics/actions/workflows/build.yml)
A JupyterLab extension.

## Requirements

- JupyterLab >= 4.0.0

## Install

To install the extension, execute:

```bash
pip install jupyterlab_athena_analytics
```

## Uninstall

To remove the extension, execute:

```bash
pip uninstall jupyterlab_athena_analytics
```

## Contributing

### Development install

Note: You will need NodeJS to build the extension package.

The `jlpm` command is JupyterLab's pinned version of
[yarn](https://yarnpkg.com/) that is installed with JupyterLab. You may use
`yarn` or `npm` in lieu of `jlpm` below.

```bash
# Clone the repo to your local environment
# Change directory to the jupyterlab_athena_analytics directory
# Install package in development mode
pip install -e "."
# Link your development version of the extension with JupyterLab
jupyter labextension develop . --overwrite
# Rebuild extension Typescript source after making changes
jlpm build
```

You can watch the source directory and run JupyterLab at the same time in different terminals to watch for changes in the extension's source and automatically rebuild the extension.

```bash
# Watch the source directory in one terminal, automatically rebuilding when needed
jlpm watch
# Run JupyterLab in another terminal
jupyter lab
```

With the watch command running, every saved change will immediately be built locally and available in your running JupyterLab. Refresh JupyterLab to load the change in your browser (you may need to wait several seconds for the extension to be rebuilt).

By default, the `jlpm build` command generates the source maps for this extension to make it easier to debug using the browser dev tools. To also generate source maps for the JupyterLab core extensions, you can run the following command:

```bash
jupyter lab build --minimize=False
```

### Development uninstall

```bash
pip uninstall jupyterlab_athena_analytics
```

In development mode, you will also need to remove the symlink created by `jupyter labextension develop`
command. To find its location, you can run `jupyter labextension list` to figure out where the `labextensions`
folder is located. Then you can remove the symlink named `jupyterlab_athena_analytics` within that folder.

### Testing the extension

#### Frontend tests

This extension is using [Jest](https://jestjs.io/) for JavaScript code testing.

To execute them, execute:

```sh
jlpm
jlpm test
```

#### Integration tests

This extension uses [Playwright](https://playwright.dev/docs/intro/) for the integration tests (aka user level tests).
More precisely, the JupyterLab helper [Galata](https://github.com/jupyterlab/jupyterlab/tree/master/galata) is used to handle testing the extension in JupyterLab.

More information are provided within the [ui-tests](./ui-tests/README.md) README.

### Packaging the extension

See [RELEASE](RELEASE.md)
